@@ -37,7 +37,9 @@ __all__ = (
     "SignInMethodType",
     "StatusType",
     "UnAuthenticatedElementType",
+    "AmplifyBackendServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -81,6 +83,7 @@ ServiceType = Literal["COGNITO"]
 SignInMethodType = Literal["EMAIL", "EMAIL_AND_PHONE_NUMBER", "PHONE_NUMBER", "USERNAME"]
 StatusType = Literal["LATEST", "STALE"]
 UnAuthenticatedElementType = Literal["CREATE_AND_UPDATE", "DELETE", "READ"]
+AmplifyBackendServiceName = Literal["amplifybackend"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -112,6 +115,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -234,6 +238,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -382,4 +387,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_backend_jobs"]
