@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Any, Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AdditionalConstraintsElementType,
     AuthenticatedElementType,
@@ -144,115 +146,83 @@ __all__ = (
 BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
     "BackendAPIAppSyncAuthSettingsTypeDef",
     {
-        "CognitoUserPoolId": str,
-        "Description": str,
-        "ExpirationTime": float,
-        "OpenIDAuthTTL": str,
-        "OpenIDClientId": str,
-        "OpenIDIatTTL": str,
-        "OpenIDIssueURL": str,
-        "OpenIDProviderName": str,
+        "CognitoUserPoolId": NotRequired[str],
+        "Description": NotRequired[str],
+        "ExpirationTime": NotRequired[float],
+        "OpenIDAuthTTL": NotRequired[str],
+        "OpenIDClientId": NotRequired[str],
+        "OpenIDIatTTL": NotRequired[str],
+        "OpenIDIssueURL": NotRequired[str],
+        "OpenIDProviderName": NotRequired[str],
     },
-    total=False,
 )
 
 BackendAPIAuthTypeTypeDef = TypedDict(
     "BackendAPIAuthTypeTypeDef",
     {
-        "Mode": ModeType,
-        "Settings": "BackendAPIAppSyncAuthSettingsTypeDef",
+        "Mode": NotRequired[ModeType],
+        "Settings": NotRequired["BackendAPIAppSyncAuthSettingsTypeDef"],
     },
-    total=False,
 )
 
 BackendAPIConflictResolutionTypeDef = TypedDict(
     "BackendAPIConflictResolutionTypeDef",
     {
-        "ResolutionStrategy": ResolutionStrategyType,
+        "ResolutionStrategy": NotRequired[ResolutionStrategyType],
     },
-    total=False,
 )
 
 BackendAPIResourceConfigTypeDef = TypedDict(
     "BackendAPIResourceConfigTypeDef",
     {
-        "AdditionalAuthTypes": Sequence["BackendAPIAuthTypeTypeDef"],
-        "ApiName": str,
-        "ConflictResolution": "BackendAPIConflictResolutionTypeDef",
-        "DefaultAuthType": "BackendAPIAuthTypeTypeDef",
-        "Service": str,
-        "TransformSchema": str,
+        "AdditionalAuthTypes": NotRequired[Sequence["BackendAPIAuthTypeTypeDef"]],
+        "ApiName": NotRequired[str],
+        "ConflictResolution": NotRequired["BackendAPIConflictResolutionTypeDef"],
+        "DefaultAuthType": NotRequired["BackendAPIAuthTypeTypeDef"],
+        "Service": NotRequired[str],
+        "TransformSchema": NotRequired[str],
     },
-    total=False,
 )
 
 BackendAuthAppleProviderConfigTypeDef = TypedDict(
     "BackendAuthAppleProviderConfigTypeDef",
     {
-        "ClientId": str,
-        "KeyId": str,
-        "PrivateKey": str,
-        "TeamId": str,
+        "ClientId": NotRequired[str],
+        "KeyId": NotRequired[str],
+        "PrivateKey": NotRequired[str],
+        "TeamId": NotRequired[str],
     },
-    total=False,
 )
 
 BackendAuthSocialProviderConfigTypeDef = TypedDict(
     "BackendAuthSocialProviderConfigTypeDef",
     {
-        "ClientId": str,
-        "ClientSecret": str,
+        "ClientId": NotRequired[str],
+        "ClientSecret": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredBackendJobRespObjTypeDef = TypedDict(
-    "_RequiredBackendJobRespObjTypeDef",
+BackendJobRespObjTypeDef = TypedDict(
+    "BackendJobRespObjTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
+        "CreateTime": NotRequired[str],
+        "Error": NotRequired[str],
+        "JobId": NotRequired[str],
+        "Operation": NotRequired[str],
+        "Status": NotRequired[str],
+        "UpdateTime": NotRequired[str],
     },
 )
-_OptionalBackendJobRespObjTypeDef = TypedDict(
-    "_OptionalBackendJobRespObjTypeDef",
-    {
-        "CreateTime": str,
-        "Error": str,
-        "JobId": str,
-        "Operation": str,
-        "Status": str,
-        "UpdateTime": str,
-    },
-    total=False,
-)
 
-
-class BackendJobRespObjTypeDef(
-    _RequiredBackendJobRespObjTypeDef, _OptionalBackendJobRespObjTypeDef
-):
-    pass
-
-
-_RequiredBackendStoragePermissionsTypeDef = TypedDict(
-    "_RequiredBackendStoragePermissionsTypeDef",
+BackendStoragePermissionsTypeDef = TypedDict(
+    "BackendStoragePermissionsTypeDef",
     {
         "Authenticated": Sequence[AuthenticatedElementType],
+        "UnAuthenticated": NotRequired[Sequence[UnAuthenticatedElementType]],
     },
 )
-_OptionalBackendStoragePermissionsTypeDef = TypedDict(
-    "_OptionalBackendStoragePermissionsTypeDef",
-    {
-        "UnAuthenticated": Sequence[UnAuthenticatedElementType],
-    },
-    total=False,
-)
-
-
-class BackendStoragePermissionsTypeDef(
-    _RequiredBackendStoragePermissionsTypeDef, _OptionalBackendStoragePermissionsTypeDef
-):
-    pass
-
 
 CloneBackendRequestRequestTypeDef = TypedDict(
     "CloneBackendRequestRequestTypeDef",
@@ -299,28 +269,14 @@ CreateBackendAPIResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef",
+CreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
+    "CreateBackendAuthForgotPasswordConfigTypeDef",
     {
         "DeliveryMethod": DeliveryMethodType,
+        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
+        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
 )
-_OptionalCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthForgotPasswordConfigTypeDef",
-    {
-        "EmailSettings": "EmailSettingsTypeDef",
-        "SmsSettings": "SmsSettingsTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateBackendAuthForgotPasswordConfigTypeDef(
-    _RequiredCreateBackendAuthForgotPasswordConfigTypeDef,
-    _OptionalCreateBackendAuthForgotPasswordConfigTypeDef,
-):
-    pass
-
 
 CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
     "CreateBackendAuthIdentityPoolConfigTypeDef",
@@ -330,73 +286,33 @@ CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendAuthMFAConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthMFAConfigTypeDef",
+CreateBackendAuthMFAConfigTypeDef = TypedDict(
+    "CreateBackendAuthMFAConfigTypeDef",
     {
         "MFAMode": MFAModeType,
+        "Settings": NotRequired["SettingsTypeDef"],
     },
 )
-_OptionalCreateBackendAuthMFAConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthMFAConfigTypeDef",
-    {
-        "Settings": "SettingsTypeDef",
-    },
-    total=False,
-)
 
-
-class CreateBackendAuthMFAConfigTypeDef(
-    _RequiredCreateBackendAuthMFAConfigTypeDef, _OptionalCreateBackendAuthMFAConfigTypeDef
-):
-    pass
-
-
-_RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthOAuthConfigTypeDef",
+CreateBackendAuthOAuthConfigTypeDef = TypedDict(
+    "CreateBackendAuthOAuthConfigTypeDef",
     {
         "OAuthGrantType": OAuthGrantTypeType,
         "OAuthScopes": Sequence[OAuthScopesElementType],
         "RedirectSignInURIs": Sequence[str],
         "RedirectSignOutURIs": Sequence[str],
+        "DomainPrefix": NotRequired[str],
+        "SocialProviderSettings": NotRequired["SocialProviderSettingsTypeDef"],
     },
 )
-_OptionalCreateBackendAuthOAuthConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthOAuthConfigTypeDef",
-    {
-        "DomainPrefix": str,
-        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
-    },
-    total=False,
-)
 
-
-class CreateBackendAuthOAuthConfigTypeDef(
-    _RequiredCreateBackendAuthOAuthConfigTypeDef, _OptionalCreateBackendAuthOAuthConfigTypeDef
-):
-    pass
-
-
-_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef",
+CreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
+    "CreateBackendAuthPasswordPolicyConfigTypeDef",
     {
         "MinimumLength": float,
+        "AdditionalConstraints": NotRequired[Sequence[AdditionalConstraintsElementType]],
     },
 )
-_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
-    {
-        "AdditionalConstraints": Sequence[AdditionalConstraintsElementType],
-    },
-    total=False,
-)
-
-
-class CreateBackendAuthPasswordPolicyConfigTypeDef(
-    _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef,
-    _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef,
-):
-    pass
-
 
 CreateBackendAuthRequestRequestTypeDef = TypedDict(
     "CreateBackendAuthRequestRequestTypeDef",
@@ -408,28 +324,15 @@ CreateBackendAuthRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthResourceConfigTypeDef",
+CreateBackendAuthResourceConfigTypeDef = TypedDict(
+    "CreateBackendAuthResourceConfigTypeDef",
     {
         "AuthResources": AuthResourcesType,
         "Service": Literal["COGNITO"],
         "UserPoolConfigs": "CreateBackendAuthUserPoolConfigTypeDef",
+        "IdentityPoolConfigs": NotRequired["CreateBackendAuthIdentityPoolConfigTypeDef"],
     },
 )
-_OptionalCreateBackendAuthResourceConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthResourceConfigTypeDef",
-    {
-        "IdentityPoolConfigs": "CreateBackendAuthIdentityPoolConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateBackendAuthResourceConfigTypeDef(
-    _RequiredCreateBackendAuthResourceConfigTypeDef, _OptionalCreateBackendAuthResourceConfigTypeDef
-):
-    pass
-
 
 CreateBackendAuthResponseTypeDef = TypedDict(
     "CreateBackendAuthResponseTypeDef",
@@ -444,77 +347,36 @@ CreateBackendAuthResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
+CreateBackendAuthUserPoolConfigTypeDef = TypedDict(
+    "CreateBackendAuthUserPoolConfigTypeDef",
     {
         "RequiredSignUpAttributes": Sequence[RequiredSignUpAttributesElementType],
         "SignInMethod": SignInMethodType,
         "UserPoolName": str,
+        "ForgotPassword": NotRequired["CreateBackendAuthForgotPasswordConfigTypeDef"],
+        "Mfa": NotRequired["CreateBackendAuthMFAConfigTypeDef"],
+        "OAuth": NotRequired["CreateBackendAuthOAuthConfigTypeDef"],
+        "PasswordPolicy": NotRequired["CreateBackendAuthPasswordPolicyConfigTypeDef"],
+        "VerificationMessage": NotRequired["CreateBackendAuthVerificationMessageConfigTypeDef"],
     },
 )
-_OptionalCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthUserPoolConfigTypeDef",
-    {
-        "ForgotPassword": "CreateBackendAuthForgotPasswordConfigTypeDef",
-        "Mfa": "CreateBackendAuthMFAConfigTypeDef",
-        "OAuth": "CreateBackendAuthOAuthConfigTypeDef",
-        "PasswordPolicy": "CreateBackendAuthPasswordPolicyConfigTypeDef",
-        "VerificationMessage": "CreateBackendAuthVerificationMessageConfigTypeDef",
-    },
-    total=False,
-)
 
-
-class CreateBackendAuthUserPoolConfigTypeDef(
-    _RequiredCreateBackendAuthUserPoolConfigTypeDef, _OptionalCreateBackendAuthUserPoolConfigTypeDef
-):
-    pass
-
-
-_RequiredCreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthVerificationMessageConfigTypeDef",
+CreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "CreateBackendAuthVerificationMessageConfigTypeDef",
     {
         "DeliveryMethod": DeliveryMethodType,
+        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
+        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
 )
-_OptionalCreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendAuthVerificationMessageConfigTypeDef",
-    {
-        "EmailSettings": "EmailSettingsTypeDef",
-        "SmsSettings": "SmsSettingsTypeDef",
-    },
-    total=False,
-)
 
-
-class CreateBackendAuthVerificationMessageConfigTypeDef(
-    _RequiredCreateBackendAuthVerificationMessageConfigTypeDef,
-    _OptionalCreateBackendAuthVerificationMessageConfigTypeDef,
-):
-    pass
-
-
-_RequiredCreateBackendConfigRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateBackendConfigRequestRequestTypeDef",
+CreateBackendConfigRequestRequestTypeDef = TypedDict(
+    "CreateBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
+        "BackendManagerAppId": NotRequired[str],
     },
 )
-_OptionalCreateBackendConfigRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateBackendConfigRequestRequestTypeDef",
-    {
-        "BackendManagerAppId": str,
-    },
-    total=False,
-)
-
-
-class CreateBackendConfigRequestRequestTypeDef(
-    _RequiredCreateBackendConfigRequestRequestTypeDef,
-    _OptionalCreateBackendConfigRequestRequestTypeDef,
-):
-    pass
-
 
 CreateBackendConfigResponseTypeDef = TypedDict(
     "CreateBackendConfigResponseTypeDef",
@@ -527,29 +389,16 @@ CreateBackendConfigResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateBackendRequestRequestTypeDef",
+CreateBackendRequestRequestTypeDef = TypedDict(
+    "CreateBackendRequestRequestTypeDef",
     {
         "AppId": str,
         "AppName": str,
         "BackendEnvironmentName": str,
+        "ResourceConfig": NotRequired[Mapping[str, Any]],
+        "ResourceName": NotRequired[str],
     },
 )
-_OptionalCreateBackendRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateBackendRequestRequestTypeDef",
-    {
-        "ResourceConfig": Mapping[str, Any],
-        "ResourceName": str,
-    },
-    total=False,
-)
-
-
-class CreateBackendRequestRequestTypeDef(
-    _RequiredCreateBackendRequestRequestTypeDef, _OptionalCreateBackendRequestRequestTypeDef
-):
-    pass
-
 
 CreateBackendResponseTypeDef = TypedDict(
     "CreateBackendResponseTypeDef",
@@ -574,28 +423,14 @@ CreateBackendStorageRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendStorageResourceConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendStorageResourceConfigTypeDef",
+CreateBackendStorageResourceConfigTypeDef = TypedDict(
+    "CreateBackendStorageResourceConfigTypeDef",
     {
         "Permissions": "BackendStoragePermissionsTypeDef",
         "ServiceName": Literal["S3"],
+        "BucketName": NotRequired[str],
     },
 )
-_OptionalCreateBackendStorageResourceConfigTypeDef = TypedDict(
-    "_OptionalCreateBackendStorageResourceConfigTypeDef",
-    {
-        "BucketName": str,
-    },
-    total=False,
-)
-
-
-class CreateBackendStorageResourceConfigTypeDef(
-    _RequiredCreateBackendStorageResourceConfigTypeDef,
-    _OptionalCreateBackendStorageResourceConfigTypeDef,
-):
-    pass
-
 
 CreateBackendStorageResponseTypeDef = TypedDict(
     "CreateBackendStorageResponseTypeDef",
@@ -626,28 +461,15 @@ CreateTokenResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteBackendAPIRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteBackendAPIRequestRequestTypeDef",
+DeleteBackendAPIRequestRequestTypeDef = TypedDict(
+    "DeleteBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
+        "ResourceConfig": NotRequired["BackendAPIResourceConfigTypeDef"],
     },
 )
-_OptionalDeleteBackendAPIRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteBackendAPIRequestRequestTypeDef",
-    {
-        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DeleteBackendAPIRequestRequestTypeDef(
-    _RequiredDeleteBackendAPIRequestRequestTypeDef, _OptionalDeleteBackendAPIRequestRequestTypeDef
-):
-    pass
-
 
 DeleteBackendAPIResponseTypeDef = TypedDict(
     "DeleteBackendAPIResponseTypeDef",
@@ -745,10 +567,9 @@ DeleteTokenResponseTypeDef = TypedDict(
 EmailSettingsTypeDef = TypedDict(
     "EmailSettingsTypeDef",
     {
-        "EmailMessage": str,
-        "EmailSubject": str,
+        "EmailMessage": NotRequired[str],
+        "EmailSubject": NotRequired[str],
     },
-    total=False,
 )
 
 GenerateBackendAPIModelsRequestRequestTypeDef = TypedDict(
@@ -791,28 +612,15 @@ GetBackendAPIModelsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetBackendAPIRequestRequestTypeDef = TypedDict(
-    "_RequiredGetBackendAPIRequestRequestTypeDef",
+GetBackendAPIRequestRequestTypeDef = TypedDict(
+    "GetBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
+        "ResourceConfig": NotRequired["BackendAPIResourceConfigTypeDef"],
     },
 )
-_OptionalGetBackendAPIRequestRequestTypeDef = TypedDict(
-    "_OptionalGetBackendAPIRequestRequestTypeDef",
-    {
-        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class GetBackendAPIRequestRequestTypeDef(
-    _RequiredGetBackendAPIRequestRequestTypeDef, _OptionalGetBackendAPIRequestRequestTypeDef
-):
-    pass
-
 
 GetBackendAPIResponseTypeDef = TypedDict(
     "GetBackendAPIResponseTypeDef",
@@ -871,26 +679,13 @@ GetBackendJobResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetBackendRequestRequestTypeDef = TypedDict(
-    "_RequiredGetBackendRequestRequestTypeDef",
+GetBackendRequestRequestTypeDef = TypedDict(
+    "GetBackendRequestRequestTypeDef",
     {
         "AppId": str,
+        "BackendEnvironmentName": NotRequired[str],
     },
 )
-_OptionalGetBackendRequestRequestTypeDef = TypedDict(
-    "_OptionalGetBackendRequestRequestTypeDef",
-    {
-        "BackendEnvironmentName": str,
-    },
-    total=False,
-)
-
-
-class GetBackendRequestRequestTypeDef(
-    _RequiredGetBackendRequestRequestTypeDef, _OptionalGetBackendRequestRequestTypeDef
-):
-    pass
-
 
 GetBackendResponseTypeDef = TypedDict(
     "GetBackendResponseTypeDef",
@@ -915,28 +710,15 @@ GetBackendStorageRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredGetBackendStorageResourceConfigTypeDef = TypedDict(
-    "_RequiredGetBackendStorageResourceConfigTypeDef",
+GetBackendStorageResourceConfigTypeDef = TypedDict(
+    "GetBackendStorageResourceConfigTypeDef",
     {
         "Imported": bool,
         "ServiceName": Literal["S3"],
+        "BucketName": NotRequired[str],
+        "Permissions": NotRequired["BackendStoragePermissionsTypeDef"],
     },
 )
-_OptionalGetBackendStorageResourceConfigTypeDef = TypedDict(
-    "_OptionalGetBackendStorageResourceConfigTypeDef",
-    {
-        "BucketName": str,
-        "Permissions": "BackendStoragePermissionsTypeDef",
-    },
-    total=False,
-)
-
-
-class GetBackendStorageResourceConfigTypeDef(
-    _RequiredGetBackendStorageResourceConfigTypeDef, _OptionalGetBackendStorageResourceConfigTypeDef
-):
-    pass
-
 
 GetBackendStorageResponseTypeDef = TypedDict(
     "GetBackendStorageResponseTypeDef",
@@ -968,30 +750,17 @@ GetTokenResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredImportBackendAuthRequestRequestTypeDef = TypedDict(
-    "_RequiredImportBackendAuthRequestRequestTypeDef",
+ImportBackendAuthRequestRequestTypeDef = TypedDict(
+    "ImportBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "NativeClientId": str,
         "UserPoolId": str,
         "WebClientId": str,
+        "IdentityPoolId": NotRequired[str],
     },
 )
-_OptionalImportBackendAuthRequestRequestTypeDef = TypedDict(
-    "_OptionalImportBackendAuthRequestRequestTypeDef",
-    {
-        "IdentityPoolId": str,
-    },
-    total=False,
-)
-
-
-class ImportBackendAuthRequestRequestTypeDef(
-    _RequiredImportBackendAuthRequestRequestTypeDef, _OptionalImportBackendAuthRequestRequestTypeDef
-):
-    pass
-
 
 ImportBackendAuthResponseTypeDef = TypedDict(
     "ImportBackendAuthResponseTypeDef",
@@ -1006,29 +775,15 @@ ImportBackendAuthResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredImportBackendStorageRequestRequestTypeDef = TypedDict(
-    "_RequiredImportBackendStorageRequestRequestTypeDef",
+ImportBackendStorageRequestRequestTypeDef = TypedDict(
+    "ImportBackendStorageRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ServiceName": Literal["S3"],
+        "BucketName": NotRequired[str],
     },
 )
-_OptionalImportBackendStorageRequestRequestTypeDef = TypedDict(
-    "_OptionalImportBackendStorageRequestRequestTypeDef",
-    {
-        "BucketName": str,
-    },
-    total=False,
-)
-
-
-class ImportBackendStorageRequestRequestTypeDef(
-    _RequiredImportBackendStorageRequestRequestTypeDef,
-    _OptionalImportBackendStorageRequestRequestTypeDef,
-):
-    pass
-
 
 ImportBackendStorageResponseTypeDef = TypedDict(
     "ImportBackendStorageResponseTypeDef",
@@ -1041,31 +796,18 @@ ImportBackendStorageResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListBackendJobsRequestRequestTypeDef = TypedDict(
-    "_RequiredListBackendJobsRequestRequestTypeDef",
+ListBackendJobsRequestRequestTypeDef = TypedDict(
+    "ListBackendJobsRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
+        "JobId": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "Operation": NotRequired[str],
+        "Status": NotRequired[str],
     },
 )
-_OptionalListBackendJobsRequestRequestTypeDef = TypedDict(
-    "_OptionalListBackendJobsRequestRequestTypeDef",
-    {
-        "JobId": str,
-        "MaxResults": int,
-        "NextToken": str,
-        "Operation": str,
-        "Status": str,
-    },
-    total=False,
-)
-
-
-class ListBackendJobsRequestRequestTypeDef(
-    _RequiredListBackendJobsRequestRequestTypeDef, _OptionalListBackendJobsRequestRequestTypeDef
-):
-    pass
-
 
 ListBackendJobsResponseTypeDef = TypedDict(
     "ListBackendJobsResponseTypeDef",
@@ -1079,9 +821,8 @@ ListBackendJobsResponseTypeDef = TypedDict(
 ListS3BucketsRequestRequestTypeDef = TypedDict(
     "ListS3BucketsRequestRequestTypeDef",
     {
-        "NextToken": str,
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListS3BucketsResponseTypeDef = TypedDict(
@@ -1096,44 +837,29 @@ ListS3BucketsResponseTypeDef = TypedDict(
 LoginAuthConfigReqObjTypeDef = TypedDict(
     "LoginAuthConfigReqObjTypeDef",
     {
-        "AwsCognitoIdentityPoolId": str,
-        "AwsCognitoRegion": str,
-        "AwsUserPoolsId": str,
-        "AwsUserPoolsWebClientId": str,
+        "AwsCognitoIdentityPoolId": NotRequired[str],
+        "AwsCognitoRegion": NotRequired[str],
+        "AwsUserPoolsId": NotRequired[str],
+        "AwsUserPoolsWebClientId": NotRequired[str],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredRemoveAllBackendsRequestRequestTypeDef = TypedDict(
-    "_RequiredRemoveAllBackendsRequestRequestTypeDef",
+RemoveAllBackendsRequestRequestTypeDef = TypedDict(
+    "RemoveAllBackendsRequestRequestTypeDef",
     {
         "AppId": str,
+        "CleanAmplifyApp": NotRequired[bool],
     },
 )
-_OptionalRemoveAllBackendsRequestRequestTypeDef = TypedDict(
-    "_OptionalRemoveAllBackendsRequestRequestTypeDef",
-    {
-        "CleanAmplifyApp": bool,
-    },
-    total=False,
-)
-
-
-class RemoveAllBackendsRequestRequestTypeDef(
-    _RequiredRemoveAllBackendsRequestRequestTypeDef, _OptionalRemoveAllBackendsRequestRequestTypeDef
-):
-    pass
-
 
 RemoveAllBackendsResponseTypeDef = TypedDict(
     "RemoveAllBackendsResponseTypeDef",
@@ -1176,62 +902,45 @@ ResponseMetadataTypeDef = TypedDict(
 S3BucketInfoTypeDef = TypedDict(
     "S3BucketInfoTypeDef",
     {
-        "CreationDate": str,
-        "Name": str,
+        "CreationDate": NotRequired[str],
+        "Name": NotRequired[str],
     },
-    total=False,
 )
 
 SettingsTypeDef = TypedDict(
     "SettingsTypeDef",
     {
-        "MfaTypes": Sequence[MfaTypesElementType],
-        "SmsMessage": str,
+        "MfaTypes": NotRequired[Sequence[MfaTypesElementType]],
+        "SmsMessage": NotRequired[str],
     },
-    total=False,
 )
 
 SmsSettingsTypeDef = TypedDict(
     "SmsSettingsTypeDef",
     {
-        "SmsMessage": str,
+        "SmsMessage": NotRequired[str],
     },
-    total=False,
 )
 
 SocialProviderSettingsTypeDef = TypedDict(
     "SocialProviderSettingsTypeDef",
     {
-        "Facebook": "BackendAuthSocialProviderConfigTypeDef",
-        "Google": "BackendAuthSocialProviderConfigTypeDef",
-        "LoginWithAmazon": "BackendAuthSocialProviderConfigTypeDef",
-        "SignInWithApple": "BackendAuthAppleProviderConfigTypeDef",
+        "Facebook": NotRequired["BackendAuthSocialProviderConfigTypeDef"],
+        "Google": NotRequired["BackendAuthSocialProviderConfigTypeDef"],
+        "LoginWithAmazon": NotRequired["BackendAuthSocialProviderConfigTypeDef"],
+        "SignInWithApple": NotRequired["BackendAuthAppleProviderConfigTypeDef"],
     },
-    total=False,
 )
 
-_RequiredUpdateBackendAPIRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateBackendAPIRequestRequestTypeDef",
+UpdateBackendAPIRequestRequestTypeDef = TypedDict(
+    "UpdateBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
+        "ResourceConfig": NotRequired["BackendAPIResourceConfigTypeDef"],
     },
 )
-_OptionalUpdateBackendAPIRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateBackendAPIRequestRequestTypeDef",
-    {
-        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateBackendAPIRequestRequestTypeDef(
-    _RequiredUpdateBackendAPIRequestRequestTypeDef, _OptionalUpdateBackendAPIRequestRequestTypeDef
-):
-    pass
-
 
 UpdateBackendAPIResponseTypeDef = TypedDict(
     "UpdateBackendAPIResponseTypeDef",
@@ -1249,50 +958,45 @@ UpdateBackendAPIResponseTypeDef = TypedDict(
 UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
     "UpdateBackendAuthForgotPasswordConfigTypeDef",
     {
-        "DeliveryMethod": DeliveryMethodType,
-        "EmailSettings": "EmailSettingsTypeDef",
-        "SmsSettings": "SmsSettingsTypeDef",
+        "DeliveryMethod": NotRequired[DeliveryMethodType],
+        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
+        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
-    total=False,
 )
 
 UpdateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
     "UpdateBackendAuthIdentityPoolConfigTypeDef",
     {
-        "UnauthenticatedLogin": bool,
+        "UnauthenticatedLogin": NotRequired[bool],
     },
-    total=False,
 )
 
 UpdateBackendAuthMFAConfigTypeDef = TypedDict(
     "UpdateBackendAuthMFAConfigTypeDef",
     {
-        "MFAMode": MFAModeType,
-        "Settings": "SettingsTypeDef",
+        "MFAMode": NotRequired[MFAModeType],
+        "Settings": NotRequired["SettingsTypeDef"],
     },
-    total=False,
 )
 
 UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
     "UpdateBackendAuthOAuthConfigTypeDef",
     {
-        "DomainPrefix": str,
-        "OAuthGrantType": OAuthGrantTypeType,
-        "OAuthScopes": Sequence[OAuthScopesElementType],
-        "RedirectSignInURIs": Sequence[str],
-        "RedirectSignOutURIs": Sequence[str],
-        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
+        "DomainPrefix": NotRequired[str],
+        "OAuthGrantType": NotRequired[OAuthGrantTypeType],
+        "OAuthScopes": NotRequired[Sequence[OAuthScopesElementType]],
+        "RedirectSignInURIs": NotRequired[Sequence[str]],
+        "RedirectSignOutURIs": NotRequired[Sequence[str]],
+        "SocialProviderSettings": NotRequired["SocialProviderSettingsTypeDef"],
     },
-    total=False,
 )
 
 UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
     {
-        "AdditionalConstraints": Sequence[AdditionalConstraintsElementType],
-        "MinimumLength": float,
+        "AdditionalConstraints": NotRequired[Sequence[AdditionalConstraintsElementType]],
+        "MinimumLength": NotRequired[float],
     },
-    total=False,
 )
 
 UpdateBackendAuthRequestRequestTypeDef = TypedDict(
@@ -1305,28 +1009,15 @@ UpdateBackendAuthRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateBackendAuthResourceConfigTypeDef = TypedDict(
-    "_RequiredUpdateBackendAuthResourceConfigTypeDef",
+UpdateBackendAuthResourceConfigTypeDef = TypedDict(
+    "UpdateBackendAuthResourceConfigTypeDef",
     {
         "AuthResources": AuthResourcesType,
         "Service": Literal["COGNITO"],
         "UserPoolConfigs": "UpdateBackendAuthUserPoolConfigTypeDef",
+        "IdentityPoolConfigs": NotRequired["UpdateBackendAuthIdentityPoolConfigTypeDef"],
     },
 )
-_OptionalUpdateBackendAuthResourceConfigTypeDef = TypedDict(
-    "_OptionalUpdateBackendAuthResourceConfigTypeDef",
-    {
-        "IdentityPoolConfigs": "UpdateBackendAuthIdentityPoolConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateBackendAuthResourceConfigTypeDef(
-    _RequiredUpdateBackendAuthResourceConfigTypeDef, _OptionalUpdateBackendAuthResourceConfigTypeDef
-):
-    pass
-
 
 UpdateBackendAuthResponseTypeDef = TypedDict(
     "UpdateBackendAuthResponseTypeDef",
@@ -1344,59 +1035,30 @@ UpdateBackendAuthResponseTypeDef = TypedDict(
 UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
     "UpdateBackendAuthUserPoolConfigTypeDef",
     {
-        "ForgotPassword": "UpdateBackendAuthForgotPasswordConfigTypeDef",
-        "Mfa": "UpdateBackendAuthMFAConfigTypeDef",
-        "OAuth": "UpdateBackendAuthOAuthConfigTypeDef",
-        "PasswordPolicy": "UpdateBackendAuthPasswordPolicyConfigTypeDef",
-        "VerificationMessage": "UpdateBackendAuthVerificationMessageConfigTypeDef",
+        "ForgotPassword": NotRequired["UpdateBackendAuthForgotPasswordConfigTypeDef"],
+        "Mfa": NotRequired["UpdateBackendAuthMFAConfigTypeDef"],
+        "OAuth": NotRequired["UpdateBackendAuthOAuthConfigTypeDef"],
+        "PasswordPolicy": NotRequired["UpdateBackendAuthPasswordPolicyConfigTypeDef"],
+        "VerificationMessage": NotRequired["UpdateBackendAuthVerificationMessageConfigTypeDef"],
     },
-    total=False,
 )
 
-_RequiredUpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
-    "_RequiredUpdateBackendAuthVerificationMessageConfigTypeDef",
+UpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "UpdateBackendAuthVerificationMessageConfigTypeDef",
     {
         "DeliveryMethod": DeliveryMethodType,
+        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
+        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
 )
-_OptionalUpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
-    "_OptionalUpdateBackendAuthVerificationMessageConfigTypeDef",
-    {
-        "EmailSettings": "EmailSettingsTypeDef",
-        "SmsSettings": "SmsSettingsTypeDef",
-    },
-    total=False,
-)
 
-
-class UpdateBackendAuthVerificationMessageConfigTypeDef(
-    _RequiredUpdateBackendAuthVerificationMessageConfigTypeDef,
-    _OptionalUpdateBackendAuthVerificationMessageConfigTypeDef,
-):
-    pass
-
-
-_RequiredUpdateBackendConfigRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateBackendConfigRequestRequestTypeDef",
+UpdateBackendConfigRequestRequestTypeDef = TypedDict(
+    "UpdateBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
+        "LoginAuthConfig": NotRequired["LoginAuthConfigReqObjTypeDef"],
     },
 )
-_OptionalUpdateBackendConfigRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateBackendConfigRequestRequestTypeDef",
-    {
-        "LoginAuthConfig": "LoginAuthConfigReqObjTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateBackendConfigRequestRequestTypeDef(
-    _RequiredUpdateBackendConfigRequestRequestTypeDef,
-    _OptionalUpdateBackendConfigRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateBackendConfigResponseTypeDef = TypedDict(
     "UpdateBackendConfigResponseTypeDef",
@@ -1409,29 +1071,16 @@ UpdateBackendConfigResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateBackendJobRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateBackendJobRequestRequestTypeDef",
+UpdateBackendJobRequestRequestTypeDef = TypedDict(
+    "UpdateBackendJobRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "JobId": str,
+        "Operation": NotRequired[str],
+        "Status": NotRequired[str],
     },
 )
-_OptionalUpdateBackendJobRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateBackendJobRequestRequestTypeDef",
-    {
-        "Operation": str,
-        "Status": str,
-    },
-    total=False,
-)
-
-
-class UpdateBackendJobRequestRequestTypeDef(
-    _RequiredUpdateBackendJobRequestRequestTypeDef, _OptionalUpdateBackendJobRequestRequestTypeDef
-):
-    pass
-
 
 UpdateBackendJobResponseTypeDef = TypedDict(
     "UpdateBackendJobResponseTypeDef",
